testutil

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 20, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateFakeClaude

func CreateFakeClaude(dir string) (binaryPath, argsFile string, err error)

CreateFakeClaude creates a fake claude binary in the given directory that captures all invocation arguments to a file. Returns the path to the binary and the path to the args capture file.

func ReadClaudeArgs

func ReadClaudeArgs(argsFile string) (string, error)

ReadClaudeArgs reads the captured arguments from the fake claude invocation.

Types

This section is empty.

Jump to