Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateFakeClaude ¶
CreateFakeClaude creates a fake claude binary in the given directory that captures all invocation arguments to a file. Returns the path to the binary and the path to the args capture file.
func ReadClaudeArgs ¶
ReadClaudeArgs reads the captured arguments from the fake claude invocation.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.